[java-identity-provider COMMIT] in /trunk/idp-authn-api/src: main/java/net/shibboleth/idp/authn/AuthenticationEngine....

noreply at shibboleth.net noreply at shibboleth.net
Fri Aug 26 00:24:30 BST 2011


Author: lajoie
Date: Fri Aug 26 00:24:29 2011
New Revision: 4035

URL: http://svn.shibboleth.net/view/java-identity-provider?rev=4035&view=rev
Log:
more work on authn/session API, now with unit tests

Added:
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthenticationWorkflowDescriptor.java   (with props)
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/UsernamePasswordSubcontext.java   (with props)
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/UsernamePrincipal.java   (with props)
    trunk/idp-authn-api/src/test/java/net/
    trunk/idp-authn-api/src/test/java/net/shibboleth/
    trunk/idp-authn-api/src/test/java/net/shibboleth/idp/
    trunk/idp-authn-api/src/test/java/net/shibboleth/idp/authn/
    trunk/idp-authn-api/src/test/java/net/shibboleth/idp/authn/AuthenticationRequestContextTest.java   (with props)
    trunk/idp-authn-api/src/test/java/net/shibboleth/idp/authn/AuthenticationWorkflowDescriptorTest.java   (with props)
    trunk/idp-authn-api/src/test/java/net/shibboleth/idp/authn/UsernamePasswordSubcontextTest.java   (with props)
    trunk/idp-authn-api/src/test/java/net/shibboleth/idp/authn/UsernamePrincipalTest.java   (with props)
    trunk/idp-authn-api/src/test/java/net/shibboleth/idp/session/
    trunk/idp-authn-api/src/test/java/net/shibboleth/idp/session/AuthenticationEventTest.java   (with props)
    trunk/idp-authn-api/src/test/java/net/shibboleth/idp/session/IdPSessionSubcontextTest.java   (with props)
    trunk/idp-authn-api/src/test/java/net/shibboleth/idp/session/IdPSessionTest.java   (with props)
    trunk/idp-authn-api/src/test/java/net/shibboleth/idp/session/ServiceSessionTest.java   (with props)
Removed:
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthenticationEngine.java
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthenticationMethod.java
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/PerformAuthentication.java
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/PrincipalCredential.java
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/PrincipalCredentialValidator.java
Modified:
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthenticationRequestContext.java
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/session/AuthenticationEvent.java
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/session/IdPSession.java
    trunk/idp-authn-api/src/main/java/net/shibboleth/idp/session/IdPSessionSubcontext.java

Modified: trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthenticationRequestContext.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthenticationRequestContext.java?rev=4035&r1=4034&r2=4035&view=diff
==============================================================================
--- trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthenticationRequestContext.java (original)
+++ trunk/idp-authn-api/src/main/java/net/shibboleth/idp/authn/AuthenticationRequestContext.java Fri Aug 26 00:24:29 2011
@@ -17,73 +17,96 @@
 
 package net.shibboleth.idp.authn;
 
-import java.util.Collection;
+import java.security.Principal;
+import java.util.ArrayList;
 import java.util.Collections;
-import java.util.SortedSet;
-import java.util.TreeSet;
+import java.util.List;
 
 import net.jcip.annotations.ThreadSafe;
-
-import org.joda.time.DateTime;
-import org.joda.time.chrono.ISOChronology;
-import org.opensaml.messaging.context.AbstractSubcontext;
+import net.shibboleth.idp.session.AuthenticationEvent;
+
+import org.opensaml.messaging.context.AbstractSubcontextContainer;
+import org.opensaml.messaging.context.Subcontext;
 import org.opensaml.messaging.context.SubcontextContainer;
-import org.opensaml.util.collections.CollectionSupport;
 
 /** A context representing the state of an authentication attempt. */
 @ThreadSafe
-public final class AuthenticationRequestContext extends AbstractSubcontext {
-
-    /** Time when the authentication process started. */
-    private final DateTime initiationInstant;
-
-    /** Whether authentication must occur even if an existing authentication method exists and is still valid. */
-    private final boolean forcingAuthentication;
-
-    /** List of requested authentication methods. */
-    private SortedSet<AuthenticationMethod> authenticationMethods;
-
-    /** Time when authentication process completed. */
-    private DateTime completionInstant;
+public final class AuthenticationRequestContext extends AbstractSubcontextContainer implements Subcontext {
+
+    /** The owner of this subcontext. */
+    private final SubcontextContainer owner;
+
+    /** Time, in milliseconds since the epoch, when the authentication process started. */
+    private final long initiationInstant;
+
+    /** Whether authentication must occur even if an existing authentication event exists and is still valid. */
+    private boolean forcingAuthentication;
+

[... 315 lines stripped ...]


More information about the commits mailing list